
nxs_analysis_tools
===============================

A suite of tools for slicing (2D) cutting (1D) and transforming (e.g., symmetrizing, interpolating, 3D-deltaPDF) nexus format (.nxs) scattering data.

Installation
------------

Fast install:

::

    pip install nxs_analysis_tools

For a manual install get this package:

::

    wget https://github.com/stevenjgomez/nxs_analysis_tools/archive/master.zip
    unzip master.zip
    rm master.zip
    cd nxs_analysis_tools-master

Install the package:

::

    python setup.py install

    
    